package com.friday.custody.service.AmbersService;

import com.baomidou.mybatisplus.extension.service.IService;
import com.friday.custody.entity.IjsxiRobotMqEntity;
import com.friday.custody.utils.PageUtils;
import com.friday.custody.utils.R;

import java.util.Map;

/**
 * 机器人调用队列
 *
 * @author K0051745
 * @email sunlightcs@gmail.com
 * @date 2022-09-22 09:32:07
 */
public interface IjsxiRobotMqService extends IService<IjsxiRobotMqEntity> {

    PageUtils queryPage(Map<String, Object> params);

    IjsxiRobotMqEntity selectInfoByAdmin(String admin);

    IjsxiRobotMqEntity selectInfoByAdminNull();

    void addRobotMq(IjsxiRobotMqEntity robotMqEntity);

    R getRPAResult(String type, String userId, String product, String admin, String code, String message);

    R queryPrepareRobot();

    void updateReadStatus(String status, String id);

    void updateRobotStatus(String status, String id);

    void updateRuningRobotTimeOut();
}

